import { ContentConfig } from "/@/components/PageContent";
import { httpList } from "/@/api/purchase/ticketReturn";

import dayjs from "dayjs";
import { h } from "vue";
import { ElImage, ElTag } from "element-plus";
import { status_options } from "./configs";

const columns = [
  {
    type: "selection",
    width: 55,
    hide: ({ checkList }) => !checkList.includes("勾选列")
  },
  {
    label: "序号",
    type: "index",
    width: 70,
    hide: ({ checkList }) => !checkList.includes("序号列")
  },
  {
    label: "对账编号",
    prop: "payNo",
    width: 180
  },
  {
    label: "对账回票申请",
    prop: "hpNo",
    width: 180
  },
  {
    label: "申请人名称",
    prop: "apply_name",
    width: 120
  },
  {
    label: "发票类型",
    prop: "invType",
    width: 120
  },
  {
    label: "状态",
    prop: "status",
    width: 120,
    cellRenderer: ({ row, props }) =>
      h(
        ElTag,
        {
          size: props.size
        },
        {
          default: () => status_options.find(s => row.status === s.value).label
        }
      )
  },
  {
    label: "联系人",
    prop: "contector"
  },
  {
    label: "发票图片",
    prop: "inv_img",
    width: 100,
    cellRenderer: ({ row }) =>
      h(ElImage, {
        src: row.inv_img,
        previewSrcList: [row.inv_img],
        previewTeleported: true
      })
  },
  {
    label: "进项设置",
    prop: "input_ticket",
    width: 100,
    cellRenderer: ({ row }) =>
      String(row.input_ticket) === "1" ? "金税" : "人工"
  },
  {
    label: "销项设置",
    prop: "out_ticket",
    width: 100,
    cellRenderer: ({ row }) =>
      String(row.out_ticket) === "1" ? "金税" : "人工"
  },
  {
    label: "开票时间",
    prop: "open_time",
    width: 150,
    formatter: ({ createTime }) =>
      dayjs(createTime).format("YYYY-MM-DD HH:mm:ss")
  },
  {
    label: "操作",
    fixed: "right",
    slot: "operation",
    width: 60
  }
];

const contentConfig: ContentConfig = {
  title: "采购回票",
  statusProp: "companyNo",
  columns,
  apis: {
    httpList
  }
};

export default contentConfig;
